@@ -1,6 +1,6 @@
 package Code::TidyAll;
-BEGIN {
-  $Code::TidyAll::VERSION = '0.16';
+{
+  $Code::TidyAll::VERSION = '0.17';
 }
 use Cwd qw(realpath);
 use Code::TidyAll::Config::INI::Reader;
@@ -26,6 +26,7 @@ has 'backup_ttl'    => ( is => 'ro', default => sub { '1 hour' } );
 has 'check_only'    => ( is => 'ro' );
 has 'data_dir'      => ( is => 'lazy' );
 has 'iterations'    => ( is => 'ro', default => sub { 1 } );
+has 'list_only'     => ( is => 'ro' );
 has 'mode'          => ( is => 'ro', default => sub { 'cli' } );
 has 'no_backups'    => ( is => 'ro' );
 has 'no_cache'      => ( is => 'ro' );
@@ -184,43 +185,45 @@ sub _plugin_conf_matches_mode {
 sub process_all {
     my $self = shift;
 
-    return $self->process_files( $self->find_matched_files );
+    return $self->process_paths( $self->find_matched_files );
 }
 
-sub process_files {
-    my ( $self, @files ) = @_;
+sub process_paths {
+    my ( $self, @paths ) = @_;
 
-    return map { $self->process_file( realpath($_) || rel2abs($_) ) } @files;
+    return map { $self->process_path( realpath($_) || rel2abs($_) ) } @paths;
 }
 
-sub list_files {
-    my ( $self, @files ) = @_;
+sub process_path {
+    my ( $self, $path ) = @_;
 
-    foreach my $file (@files) {
-        $file = realpath($file) || rel2abs($file);
-        my $path = $self->_small_path($file);
-        if ( my @plugins = $self->plugins_for_path($path) ) {
-            printf( "%s (%s)\n", $path, join( ", ", map { $_->name } @plugins ) );
+    if ( -d $path ) {
+        if ( $self->recursive ) {
+            return $self->process_paths( map { "$path/$_" } read_dir($path) );
         }
+        else {
+            return ( $self->_error_result( "$path: is a directory (try -r/--recursive)", $path ) );
+        }
+    }
+    elsif ( -f $path ) {
+        return ( $self->process_file($path) );
+    }
+    else {
+        return ( $self->_error_result( "$path: not a file or directory", $path ) );
     }
 }
 
 sub process_file {
     my ( $self, $file ) = @_;
+    die "$file is not a file" unless -f $file;
+
     my $path = $self->_small_path($file);
 
-    if ( -d $file ) {
-        if ( $self->recursive ) {
-            return $self->process_dir($file);
+    if ( $self->list_only ) {
+        if ( my @plugins = $self->plugins_for_path($path) ) {
+            printf( "%s (%s)\n", $path, join( ", ", map { $_->name } @plugins ) );
         }
-        else {
-            print "$path: is a directory (try -r/--recursive)";
-            return;
-        }
-    }
-    elsif ( !-f $file ) {
-        print "$path: not a file or directory\n";
-        return;
+        return Code::TidyAll::Result->new( path => $path, state => 'checked' );
     }
 
     my $cache     = $self->no_cache ? undef : $self->cache;
@@ -248,14 +251,6 @@ sub process_file {
     return $result;
 }
 
-sub process_dir {
-    my ( $self, $dir ) = @_;
-
-    foreach my $subfile ( read_dir($dir) ) {
-        $self->process_file("$dir/$subfile");
-    }
-}
-
 sub process_source {
     my ( $self, $contents, $path ) = @_;
 
@@ -301,8 +296,7 @@ sub process_source {
     }
 
     if ($error) {
-        $self->msg( "%s", $error );
-        return Code::TidyAll::Result->new( path => $path, state => 'error', error => $error );
+        return $self->_error_result( $error, $path );
     }
     elsif ($was_tidied) {
         return Code::TidyAll::Result->new(
@@ -461,7 +455,6 @@ sub _small_path {
 sub _file_sig {
     my ( $self, $file, $contents ) = @_;
     my $last_mod = ( stat($file) )[9];
-    $contents = read_file($file) if !defined($contents);
     return $self->_sig( [ $self->base_sig, $last_mod, $contents ] );
 }
 
@@ -481,9 +474,15 @@ sub msg {
     printf "$format\n", @params;
 }
 
+sub _error_result {
+    my ( $self, $msg, $path ) = @_;
+    $self->msg( "%s", $msg );
+    return Code::TidyAll::Result->new( path => $path, state => 'error', error => $msg );
+}
+
 1;
 
-
+__END__
 
 =pod
 
@@ -493,7 +492,7 @@ Code::TidyAll - Engine for tidyall, your all-in-one code tidier and validator
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 SYNOPSIS
 
@@ -519,11 +518,7 @@ version 0.16
 
     # then...
 
-    $ct->process_files($file1, $file2);
-
-    # or
-
-    $ct->process_all();
+    $ct->process_paths($file1, $file2);
 
 =head1 DESCRIPTION
 
@@ -595,13 +590,10 @@ C<backup_ttl> here).
 
 =over
 
-=item process_all
+=item process_paths (path, ...)
 
-Process all files; this implements the C<tidyall -a> option.
-
-=item process_files (file, ...)
-
-Call L</process_file> on each file. Return a list of
+Call L</process_file> on each file; descend recursively into each directory if
+the C<recursive> flag is on. Return a list of
 L<Code::TidyAll::Result|Code::TidyAll::Result> objects, one for each file.
 
 =item process_file (file)
@@ -651,6 +643,10 @@ Class method. Start in the I<start_dir> and work upwards, looking for one of
 the I<conf_names>.  Return the pathname if found or throw an error if not
 found.
 
+=item find_matched_files
+
+Returns a list of sorted files that match at least one plugin in configuration.
+
 =back
 
 =head1 SEE ALSO
@@ -669,7 +665,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
