@@ -1,6 +1,6 @@
 package Code::TidyAll::SVN::Precommit;
-BEGIN {
-  $Code::TidyAll::SVN::Precommit::VERSION = '0.16';
+{
+  $Code::TidyAll::SVN::Precommit::VERSION = '0.17';
 }
 use Capture::Tiny qw(capture_stdout capture_stderr);
 use Code::TidyAll;
@@ -92,7 +92,7 @@ sub check {
                 %{ $self->tidyall_options },
             );
             my $stdout = capture_stdout {
-                push( @results, $tidyall->process_files( map { "$tempdir/$_" } @files ) );
+                push( @results, $tidyall->process_paths( map { "$tempdir/$_" } @files ) );
             };
             if ($stdout) {
                 chomp($stdout);
@@ -162,7 +162,7 @@ sub cat_file {
 
 1;
 
-
+__END__
 
 =pod
 
@@ -173,7 +173,7 @@ to be tidyall'd
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 SYNOPSIS
 
@@ -322,7 +322,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
