@@ -1,6 +1,6 @@
 package Code::TidyAll::t::Plugin::JSBeautify;
-BEGIN {
-  $Code::TidyAll::t::Plugin::JSBeautify::VERSION = '0.16';
+{
+  $Code::TidyAll::t::Plugin::JSBeautify::VERSION = '0.17';
 }
 use Test::Class::Most parent => 'Code::TidyAll::t::Plugin';
 
@@ -17,11 +17,6 @@ sub test_main : Tests {
         conf        => { argv => '--indent-size 3 --brace-style expand' },
         expect_tidy => 'sp.toggleResult = function(id)\n{\n   foo(id)\n}\n',
     );
-    $self->tidyall(
-        source       => $source,
-        conf         => { argv => '--badoption' },
-        expect_error => qr/exited with error/
-    );
 }
 
 1;
